@@ -1,33 +1,34 @@
 /*============================================================================
-*
-*   WCSLIB 4.2 - an implementation of the FITS WCS convention.
-*   Copyright (C) 1995-2005, Mark Calabretta
-*
-*   WCSLIB is free software; you can redistribute it and/or modify it under
-*   the terms of the GNU General Public License as published by the Free
-*   Software Foundation; either version 2 of the License, or (at your option)
-*   any later version.
-*
-*   WCSLIB is distributed in the hope that it will be useful, but WITHOUT ANY
-*   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-*   FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
-*   details.
-*
-*   You should have received a copy of the GNU General Public License along
-*   with WCSLIB; if not, write to the Free Software Foundation, Inc.,
-*   59 Temple Place, Suite 330, Boston, MA  02111-1307, USA
-*
-*   Correspondence concerning WCSLIB may be directed to:
-*      Internet email: mcalabre@atnf.csiro.au
-*      Postal address: Dr. Mark Calabretta
-*                      Australia Telescope National Facility, CSIRO
-*                      PO Box 76
-*                      Epping NSW 1710
-*                      AUSTRALIA
-*
-*   Author: Mark Calabretta, Australia Telescope National Facility
-*   http://www.atnf.csiro.au/~mcalabre/index.html
-*   $Id: tlog.c,v 4.2 2005/09/22 02:15:15 cal103 Exp $
+
+    WCSLIB 4.3 - an implementation of the FITS WCS standard.
+    Copyright (C) 1995-2007, Mark Calabretta
+
+    This file is part of WCSLIB.
+
+    WCSLIB is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License as published by the
+    Free Software Foundation, either version 3 of the License, or (at your
+    option) any later version.
+
+    WCSLIB is distributed in the hope that it will be useful, but WITHOUT ANY
+    WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+    more details.
+
+    You should have received a copy of the GNU Lesser General Public License
+    along with WCSLIB.  If not, see <http://www.gnu.org/licenses/>.
+
+    Correspondence concerning WCSLIB may be directed to:
+       Internet email: mcalabre@atnf.csiro.au
+       Postal address: Dr. Mark Calabretta
+                       Australia Telescope National Facility, CSIRO
+                       PO Box 76
+                       Epping NSW 1710
+                       AUSTRALIA
+
+    Author: Mark Calabretta, Australia Telescope National Facility
+    http://www.atnf.csiro.au/~mcalabre/index.html
+    $Id: tlog.c,v 4.3 2007/12/27 05:35:51 cal103 Exp $
 *=============================================================================
 *
 *   tlog tests the logarithmic coordinate transformation routines for closure.
@@ -74,12 +75,12 @@ int main()
           x0[NCRD-1], x0[1] - x0[0]);
 
    /* Convert the first to the second. */
-   if (status = logx2s(crval, NCRD, 1, 1, x0, logc, stat1)) {
+   if ((status = logx2s(crval, NCRD, 1, 1, x0, logc, stat1))) {
       printf("logx2s ERROR %d: %s.\n", status, log_errmsg[status]);
    }
 
    /* Convert the second back to the first. */
-   if (status = logs2x(crval, NCRD, 1, 1, logc, x1, stat2)) {
+   if ((status = logs2x(crval, NCRD, 1, 1, logc, x1, stat2))) {
       printf("logs2x ERROR %d: %s.\n", status, log_errmsg[status]);
    }
 
